=== modified file '.bzrignore'
--- .bzrignore	2012-02-10 11:55:55 +0000
+++ .bzrignore	2012-02-20 15:15:32 +0000
@@ -16,5 +16,8 @@
 ./parts
 ./pserv.log
 ./pserv.pid
+./services/*/log/supervise
+./services/*/supervise
+./services/scan.*
 ./TAGS
 ./tags

=== modified file 'HACKING.txt'
--- HACKING.txt	2012-02-16 15:45:16 +0000
+++ HACKING.txt	2012-02-20 15:15:32 +0000
@@ -23,13 +23,16 @@
 
 Prerequisites
 =============
+
 You will need to manually install Postgres 9.1 (postgresql-9.1 and
-libpq-dev), RabbitMQ (rabbitmq-server), python-dev and make::
-
-    $ sudo apt-get install postgresql-9.1 libpq-dev rabbitmq-server python-dev make
-
-Also, you might want to install Bazaar (bzr) to grab the source code directly
-from Launchpad::
+libpq-dev), RabbitMQ (rabbitmq-server), python-dev, daemontools, and
+make::
+
+    $ sudo apt-get install postgresql-9.1 libpq-dev rabbitmq-server
+    $ sudo apt-get install python-dev daemontools make
+
+Also, you might want to install Bazaar (``bzr``) to grab the source
+code directly from Launchpad::
 
     $ sudo apt-get install bzr
 
@@ -49,6 +52,7 @@
 
     $ bzr branch lp:maas maas && cd maas
 
+
 Development MaaS server setup
 =============================
 

=== modified file 'Makefile'
--- Makefile	2012-02-15 17:13:37 +0000
+++ Makefile	2012-02-20 15:15:32 +0000
@@ -67,7 +67,7 @@
 	find . -type f -name '*.py[co]' -print0 | xargs -r0 $(RM)
 	find . -type f -name '*~' -print0 | xargs -r0 $(RM)
 
-distclean: clean pserv-stop
+distclean: clean shutdown
 	utilities/maasdb delete-cluster ./db/
 	$(RM) -r eggs develop-eggs
 	$(RM) -r bin build dist logs parts
@@ -76,17 +76,31 @@
 	$(RM) docs/api.rst
 	$(RM) -r docs/_build/
 
-pserv.pid: bin/twistd.pserv
-	bin/twistd.pserv --pidfile=$@ maas-pserv --config-file=etc/pserv.yaml
-
-pserv-start: pserv.pid
-
-pserv-stop:
-	{ test -e pserv.pid && cat pserv.pid; } | xargs --no-run-if-empty kill
-
-run: bin/maas dev-db pserv.pid
+run: bin/maas dev-db start
 	bin/maas runserver 8000 --settings=maas.demo
 
+services/scan.pid:
+	@svscan services > services/scan.log 2>&1 <&- & \
+	    echo $$! > services/scan.pid
+
+start: bin/twistd.pserv dev-db services/scan.pid
+	@find services -type f -name run -printf '%h\0' \
+	    | xargs -n1 -0 svc -u
+
+stop:
+	@find services -type f -name run -printf '%h\0' \
+	    | xargs -n1 -0 svc -d
+
+status: services
+	@find services -type f -name run -printf '%h\0' \
+	    | xargs -n1 -0 svstat
+
+shutdown: pidfile=services/scan.pid
+shutdown:
+	@test ! -f $(pidfile) || { kill `cat $(pidfile)` && $(RM) $(pidfile); }
+	@find services -type f -name run -printf '%h\0' \
+	    | xargs -n1 -0 svc -dx
+
 harness: bin/maas dev-db
 	bin/maas shell
 
@@ -95,5 +109,5 @@
 
 .PHONY: \
     build check clean dev-db distclean doc \
-    harness lint pserv-start pserv-stop run \
-    syncdb test sampledata
+    harness lint run shutdown syncdb test \
+    sampledata start stop status \

=== added directory 'services'
=== added directory 'services/pserv'
=== added directory 'services/pserv/log'
=== added file 'services/pserv/log/run'
--- services/pserv/log/run	1970-01-01 00:00:00 +0000
+++ services/pserv/log/run	2012-02-20 15:15:32 +0000
@@ -0,0 +1,14 @@
+#!/usr/bin/env bash
+# Copyright 2012 Canonical Ltd.  This software is licensed under the
+# GNU Affero General Public License version 3 (see the file LICENSE).
+
+# Exit immediately if a command exits with a non-zero status.
+set -o errexit
+# Treat unset variables as an error when substituting.
+set -o nounset
+
+# Exec log rotation for the Provisioning Server.
+logdir="../../../logs/pserv"
+mkdir -p "${logdir}"
+# Rotate when logs reach 1MB, keeping no more than 10.
+exec multilog s1048576 n10 "${logdir}"

=== added file 'services/pserv/run'
--- services/pserv/run	1970-01-01 00:00:00 +0000
+++ services/pserv/run	2012-02-20 15:15:32 +0000
@@ -0,0 +1,13 @@
+#!/usr/bin/env bash
+# Copyright 2012 Canonical Ltd.  This software is licensed under the
+# GNU Affero General Public License version 3 (see the file LICENSE).
+
+# Exit immediately if a command exits with a non-zero status.
+set -o errexit
+# Treat unset variables as an error when substituting.
+set -o nounset
+
+# Exec the Provisioning Server.
+script="$(readlink -f ../../bin/twistd.pserv)"
+config="$(readlink -f ../../etc/pserv.yaml)"
+exec "${script}" --nodaemon maas-pserv --config-file "${config}"

